---
description: :Language-specific getting started guides overview
keywords: guides, docker, language, node, java, python, go, golang, .net
title: Overview
toc_min: 1
toc_max: 2
---

The language-specific getting started guides walk you through the process of setting up your development environment and start containerizing language-specific applications using Docker. The learning modules contain best practices and guidelines that explain how to create a new Dockerfile in your preferred language, what to include in the Docker image, how to develop and run your Docker image, set up a CI/CD pipeline, and finally provides information on how to push the application you've developed to the cloud.

In addition to the language-specific modules, Docker documentation also provides guidelines to build and efficiently manage your development environment. You can find information on the best practices for writing Dockerfiles, building and managing images efficiently, gaining performance improvements by building images using BuildKit, etc. You can also find specific instructions on how to keep your images small, and how to persist application data, how to use multi-stage builds, etc.

For more information, refer to the following topics:

* [Best practices for writing Dockerfiles](../develop/develop-images/dockerfile_best-practices.md)
* [Docker development best practices](../develop/dev-best-practices.md)
* [Build images with BuildKit](../build/buildkit/index.md#getting-started)

## Language-specific getting started guides

Learn how to set up your Docker environment and start containerizing your applications. Choose a language below to get started.

<div class="grid grid-cols-3 auto-rows-fr sm:flex-col sm:h-auto gap-4">
    <div class="flex items-center flex-1 shadow p-4">
        <a href="/language/nodejs/"><img class="m-auto rounded" src="/language/images/nodejs.png" alt="Develop with Node"></a>
    </div>
    <div class="flex items-center flex-1 shadow p-4">
        <a href="/language/python/"><img class="m-auto rounded" src="/language/images/python.png" alt="Develop with Python"></a>
    </div>
    <div class="flex items-center flex-1 shadow p-4">
        <a href="/language/java/"><img class="m-auto rounded" src="/language/images/java.png" alt="Develop with Java"></a>
    </div>
    <div class="flex items-center flex-1 shadow p-4">
        <a href="/language/golang/"><img class="m-auto rounded" src="/language/images/golang.png" alt="Develop with Go"></a>
    </div>
    <div class="flex items-center flex-1 shadow p-4">
        <a href="/language/dotnet/"><img class="m-auto rounded" src="/language/images/c-sharp.png" alt="Develop with C#"></a>
    </div>
    <div class="flex items-center flex-1 shadow p-4">
        <a href="/language/rust/"><img class="m-auto rounded" src="/language/images/rust-logo.png" alt="Develop with Rust"></a>
    </div>
</div>